==> symfony_5.4.4+dfsg.orig.tar.xz: symfony-5.4.4/src/Symfony/Component/Intl/Resources/data/scripts/fi.php <==
<?php

return [
    'Names' => [
        'Adlm' => 'fulanin adlam-aakkosto',
        'Afak' => 'afaka',
        'Aghb' => 'kaukasianalbanialainen',
        'Ahom' => 'ahom',
        'Arab' => 'arabialainen',
        'Aran' => 'nastaliq',
        'Armi' => 'valtakunnanaramealainen',
        'Armn' => 'armenialainen',
        'Avst' => 'avestalainen',
        'Bali' => 'balilainen',
        'Bamu' => 'bamum',
        'Bass' => 'bassa',
        'Batk' => 'batakilainen',
        'Beng' => 'bengalilainen',
        'Bhks' => 'sanskritin bhaiksuki-aakkosto',
        'Blis' => 'bliss-symbolit',
        'Bopo' => 'bopomofo',
        'Brah' => 'brahmi',
        'Brai' => 'braille-pistekirjoitus',
        'Bugi' => 'bugilainen',
        'Buhd' => 'buhidilainen',
        'Cakm' => 'chakmalainen',
        'Cans' => 'kanadalaisten alkuperäiskansojen yhtenäistetty tavukirjoitus',
        'Cari' => 'kaarialainen',
        'Cham' => 'tšamilainen',
        'Cher' => 'cherokeelainen',
        'Chrs' => 'horemzi',
        'Cirt' => 'cirth',
        'Copt' => 'koptilainen',
        'Cpmn' => 'kypro-minolainen',
        'Cprt' => 'muinaiskyproslainen',
        'Cyrl' => 'kyrillinen',
        'Cyrs' => 'kyrillinen muinaiskirkkoslaavimuunnelma',
        'Deva' => 'devanagari',
        'Diak' => 'dives akuru',
        'Dogr' => 'dogri',
        'Dsrt' => 'deseret',
        'Dupl' => 'Duployén pikakirjoitus',
        'Egyd' => 'egyptiläinen demoottinen',
        'Egyh' => 'egyptiläinen hieraattinen',
        'Egyp' => 'egyptiläiset hieroglyfit',
        'Elba' => 'elbasanilainen',
        'Elym' => 'elymealainen',
        'Ethi' => 'etiopialainen',
        'Geok' => 'muinaisgeorgialainen',
        'Geor' => 'georgialainen',
        'Glag' => 'glagoliittinen',
        'Gong' => 'gondin gunjala',
        'Gonm' => 'masaram-gondi',
        'Goth' => 'goottilainen',
        'Gran' => 'grantha',
        'Grek' => 'kreikkalainen',
        'Gujr' => 'gudžaratilainen',
        'Guru' => 'gurmukhi',
        'Hanb' => 'kiinan han ja bopomofo',
        'Hang' => 'hangul',
        'Hani' => 'kiinalainen han',
        'Hano' => 'hanunoolainen',
        'Hans' => 'yksinkertaistettu',
        'Hant' => 'perinteinen',
        'Hatr' => 'hatralainen',
        'Hebr' => 'heprealainen',
        'Hira' => 'hiragana',
        'Hluw' => 'anatolialaiset hieroglyfit',
        'Hmng' => 'pahawh hmong',
        'Hmnp' => 'hmongin nyiakeng puachue',
        'Hrkt' => 'japanin tavumerkistöt',
        'Hung' => 'muinaisunkarilainen',
        'Inds' => 'induslainen',
        'Ital' => 'muinaisitalialainen',
        'Jamo' => 'korean hangulin jamo-elementit',
        'Java' => 'jaavalainen',
        'Jpan' => 'japanilainen',
        'Jurc' => 'džurtšen',
        'Kali' => 'kayah li',
        'Kana' => 'katakana',
        'Khar' => 'kharosthi',
        'Khmr' => 'khmeriläinen',
        'Khoj' => 'khojki',
        'Kits' => 'kitaanin pieni merkistö',
        'Knda' => 'kannadalainen',
        'Kore' => 'korealainen',
        'Kpel' => 'kpelle',
        'Kthi' => 'kaithi',
        'Lana' => 'lanna',
        'Laoo' => 'laolainen',
        'Latf' => 'latinalainen fraktuuramuunnelma',
        'Latg' => 'latinalainen gaelimuunnelma',
        'Latn' => 'latinalainen',
        'Lepc' => 'lepchalainen',
        'Limb' => 'limbulainen',
        'Lina' => 'lineaari-A',
        'Linb' => 'lineaari-B',
        'Lisu' => 'Fraserin aakkoset',
        'Loma' => 'loma',
        'Lyci' => 'lyykialainen',
        'Lydi' => 'lyydialainen',
        'Mahj' => 'mahajanilainen',
        'Maka' => 'makassar',
        'Mand' => 'mandealainen',
        'Mani' => 'manikealainen',
        'Marc' => 'tiibetiläinen marchan-kirjoitus',
        'Maya' => 'maya-hieroglyfit',
        'Medf' => 'medefaidrin',
        'Mend' => 'mende',
        'Merc' => 'meroiittinen kursiivikirjoitus',
        'Mero' => 'meroiittinen',
        'Mlym' => 'malajalamilainen',
        'Modi' => 'modi-aakkoset',
        'Mong' => 'mongolilainen',
        'Moon' => 'moon-kohokirjoitus',
        'Mroo' => 'mro',
        'Mtei' => 'meitei',
        'Mult' => 'multanilainen',
        'Mymr' => 'burmalainen',
        'Nand' => 'nandinagari',
        'Narb' => 'muinaispohjoisarabialainen',
        'Nbat' => 'nabatealainen',
        'Newa' => 'newarin newa-tavukirjoitus',
        'Nkgb' => 'naxi geba',
        'Nkoo' => 'n’ko',
        'Nshu' => 'nüshu',
        'Ogam' => 'ogam',
        'Olck' => 'ol chiki',
        'Orkh' => 'orkhon',
        'Orya' => 'orijalainen',
        'Osge' => 'osagen aakkosto',
        'Osma' => 'osmanjalainen',
        'Ougr' => 'vanha uiguurilainen',
        'Palm' => 'palmyralainen',
        'Pauc' => 'zotuallai',
        'Perm' => 'muinaispermiläinen',
        'Phag' => 'phags-pa',
        'Phli' => 'piirtokirjoituspahlavilainen',
        'Phlp' => 'psalttaripahlavilainen',
        'Phlv' => 'kirjapahlavilainen',
        'Phnx' => 'foinikialainen',
        'Plrd' => 'Pollardin foneettinen',
        'Prti' => 'piirtokirjoitusparthialainen',
        'Qaag' => 'burmalainen zawgyi-toteutus',
        'Rjng' => 'rejang',
        'Rohg' => 'rohingalainen hanifi',
        'Roro' => 'rongorongo',
        'Runr' => 'riimukirjoitus',
        'Samr' => 'samarianaramealainen',
        'Sara' => 'sarati',
        'Sarb' => 'muinaiseteläarabialainen',
        'Saur' => 'saurashtra',
        'Sgnw' => 'SignWriting',
        'Shaw' => 'shaw’lainen',
        'Shrd' => 'šarada',
        'Sidd' => 'siddham-tavukirjoitus',
        'Sind' => 'khudabadi',
        'Sinh' => 'sinhalilainen',
        'Sogd' => 'sogdialainen',
        'Sogo' => 'muinaissogdialainen',
        'Sora' => 'sorang sompeng',
        'Soyo' => 'soyombo-kirjaimisto',
        'Sund' => 'sundalainen',
        'Sylo' => 'syloti nagri',
        'Syrc' => 'syyrialainen',
        'Syre' => 'syyrialainen estrangelo-muunnelma',
        'Syrj' => 'syyrialainen läntinen muunnelma',
        'Syrn' => 'syyrialainen itäinen muunnelma',
        'Tagb' => 'tagbanwalainen',
        'Takr' => 'takri',
        'Tale' => 'tailelainen',
        'Talu' => 'uusi tailuelainen',
        'Taml' => 'tamililainen',
        'Tang' => 'tangut',
        'Tavt' => 'tai viet',
        'Telu' => 'telugulainen',
        'Teng' => 'tengwar',
        'Tfng' => 'tifinagh',
        'Tglg' => 'tagalogilainen',
        'Thaa' => 'thaana',
        'Thai' => 'thailainen',
        'Tibt' => 'tiibetiläinen',
        'Tirh' => 'tirhuta',
        'Tnsa' => 'tangsa',
        'Toto' => 'toto',
        'Ugar' => 'ugaritilainen',
        'Vaii' => 'vailainen',
        'Visp' => 'näkyvä puhe',
        'Vith' => 'vithkuqi',
        'Wara' => 'varang kshiti',
        'Wcho' => 'wancholainen',
        'Wole' => 'woleai',
        'Xpeo' => 'muinaispersialainen',
        'Xsux' => 'sumerilais-akkadilainen nuolenpääkirjoitus',
        'Yezi' => 'jesidi',
        'Yiii' => 'yiläinen',
        'Zanb' => 'zanabazar-neliökirjaimisto',
        'Zinh' => 'peritty',
        'Zmth' => 'matemaattinen',
        'Zsye' => 'emoji-symbolit',
        'Zsym' => 'symbolit',
        'Zxxx' => 'kirjoittamaton',
        'Zyyy' => 'määrittämätön',
    ],
];

==> symfony_7.4.2+dfsg.orig.tar.xz: symfony-7.4.2/src/Symfony/Component/Intl/Resources/data/scripts/fi.php <==
<?php

return [
    'Names' => [
        'Adlm' => 'fulanin adlam-aakkosto',
        'Afak' => 'afaka',
        'Aghb' => 'kaukasianalbanialainen',
        'Ahom' => 'ahom',
        'Arab' => 'arabialainen',
        'Aran' => 'nastaliq',
        'Armi' => 'valtakunnanaramealainen',
        'Armn' => 'armenialainen',
        'Avst' => 'avestalainen',
        'Bali' => 'balilainen',
        'Bamu' => 'bamum',
        'Bass' => 'bassa',
        'Batk' => 'batakilainen',
        'Beng' => 'bengalilainen',
        'Berf' => 'beria-aakkosto',
        'Bhks' => 'sanskritin bhaiksuki-aakkosto',
        'Blis' => 'bliss-symbolit',
        'Bopo' => 'bopomofo',
        'Brah' => 'brahmi',
        'Brai' => 'braille-pistekirjoitus',
        'Bugi' => 'bugilainen',
        'Buhd' => 'buhidilainen',
        'Cakm' => 'chakmalainen',
        'Cans' => 'kanadalaisten alkuperäiskansojen yhtenäistetty tavukirjoitus',
        'Cari' => 'kaarialainen',
        'Cham' => 'tšamilainen',
        'Cher' => 'cherokeelainen',
        'Chrs' => 'horemzi',
        'Cirt' => 'cirth',
        'Copt' => 'koptilainen',
        'Cpmn' => 'kypro-minolainen',
        'Cprt' => 'muinaiskyproslainen',
        'Cyrl' => 'kyrillinen',
        'Cyrs' => 'kyrillinen muinaiskirkkoslaavimuunnelma',
        'Deva' => 'devanagari',
        'Diak' => 'dives akuru',
        'Dogr' => 'dogri',
        'Dsrt' => 'deseret',
        'Dupl' => 'Duployén pikakirjoitus',
        'Egyd' => 'egyptiläinen demoottinen',
        'Egyh' => 'egyptiläinen hieraattinen',
        'Egyp' => 'egyptiläiset hieroglyfit',
        'Elba' => 'elbasanilainen',
        'Elym' => 'elymealainen',
        'Ethi' => 'etiopialainen',
        'Gara' => 'garay',
        'Geok' => 'muinaisgeorgialainen',
        'Geor' => 'georgialainen',
        'Glag' => 'glagoliittinen',
        'Gong' => 'gondin gunjala',
        'Gonm' => 'masaram-gondi',
        'Goth' => 'goottilainen',
        'Gran' => 'grantha',
        'Grek' => 'kreikkalainen',
        'Gujr' => 'gudžaratilainen',
        'Gukh' => 'gurung khema -aakkosto',
        'Guru' => 'gurmukhi',
        'Hanb' => 'kiinan han ja bopomofo',
        'Hang' => 'hangul',
        'Hani' => 'kiinalainen han',
        'Hano' => 'hanunoolainen',
        'Hans' => 'yksinkertaistettu',
        'Hant' => 'perinteinen',
        'Hatr' => 'hatralainen',
        'Hebr' => 'heprealainen',
        'Hira' => 'hiragana',
        'Hluw' => 'anatolialaiset hieroglyfit',
        'Hmng' => 'pahawh hmong',
        'Hmnp' => 'hmongin nyiakeng puachue',
        'Hrkt' => 'japanin tavumerkistöt',
        'Hung' => 'muinaisunkarilainen',
        'Inds' => 'induslainen',
        'Ital' => 'muinaisitalialainen',
        'Jamo' => 'korean hangulin jamo-elementit',
        'Java' => 'jaavalainen',
        'Jpan' => 'japanilainen',
        'Jurc' => 'džurtšen',
        'Kali' => 'kayah li',
        'Kana' => 'katakana',
        'Kawi' => 'kawi',
        'Khar' => 'kharosthi',
        'Khmr' => 'khmeriläinen',
        'Khoj' => 'khojki',
        'Kits' => 'kitaanin pieni merkistö',
        'Knda' => 'kannadalainen',
        'Kore' => 'korealainen',
        'Kpel' => 'kpelle',
        'Krai' => 'kirat rai',
        'Kthi' => 'kaithi',
        'Lana' => 'lanna',
        'Laoo' => 'laolainen',
        'Latf' => 'latinalainen fraktuuramuunnelma',
        'Latg' => 'latinalainen gaelimuunnelma',
        'Latn' => 'latinalainen',
        'Lepc' => 'lepchalainen',
        'Limb' => 'limbulainen',
        'Lina' => 'lineaari-A',
        'Linb' => 'lineaari-B',
        'Lisu' => 'Fraserin aakkoset',
        'Loma' => 'loma',
        'Lyci' => 'lyykialainen',
        'Lydi' => 'lyydialainen',
        'Mahj' => 'mahajanilainen',
        'Maka' => 'makassar',
        'Mand' => 'mandealainen',
        'Mani' => 'manikealainen',
        'Marc' => 'tiibetiläinen marchan-kirjoitus',
        'Maya' => 'maya-hieroglyfit',
        'Medf' => 'medefaidrin',
        'Mend' => 'mende',
        'Merc' => 'meroiittinen kursiivikirjoitus',
        'Mero' => 'meroiittinen',
        'Mlym' => 'malajalamilainen',
        'Modi' => 'modi-aakkoset',
        'Mong' => 'mongolilainen',
        'Moon' => 'moon-kohokirjoitus',
        'Mroo' => 'mro',
        'Mtei' => 'meitei',
        'Mult' => 'multanilainen',
        'Mymr' => 'burmalainen',
        'Nagm' => 'Nagin mundariaakkoset',
        'Nand' => 'nandinagari',
        'Narb' => 'muinaispohjoisarabialainen',
        'Nbat' => 'nabatealainen',
        'Newa' => 'newarin newa-tavukirjoitus',
        'Nkgb' => 'naxi geba',
        'Nkoo' => 'n’ko',
        'Nshu' => 'nüshu',
        'Ogam' => 'ogam',
        'Olck' => 'ol chiki',
        'Onao' => 'ol onal',
        'Orkh' => 'orkhon',
        'Orya' => 'orijalainen',
        'Osge' => 'osagen aakkosto',
        'Osma' => 'osmanjalainen',
        'Ougr' => 'vanha uiguurilainen',
        'Palm' => 'palmyralainen',
        'Pauc' => 'zotuallai',
        'Perm' => 'muinaispermiläinen',
        'Phag' => 'phags-pa',
        'Phli' => 'piirtokirjoituspahlavilainen',
        'Phlp' => 'psalttaripahlavilainen',
        'Phlv' => 'kirjapahlavilainen',
        'Phnx' => 'foinikialainen',
        'Plrd' => 'Pollardin foneettinen',
        'Prti' => 'piirtokirjoitusparthialainen',
        'Qaag' => 'burmalainen zawgyi-toteutus',
        'Rjng' => 'rejang',
        'Rohg' => 'rohingalainen hanifi',
        'Roro' => 'rongorongo',
        'Runr' => 'riimukirjoitus',
        'Samr' => 'samarianaramealainen',
        'Sara' => 'sarati',
        'Sarb' => 'muinaiseteläarabialainen',
        'Saur' => 'saurashtra',
        'Sgnw' => 'SignWriting',
        'Shaw' => 'shaw’lainen',
        'Shrd' => 'šarada',
        'Sidd' => 'siddham-tavukirjoitus',
        'Sind' => 'khudabadi',
        'Sinh' => 'sinhalilainen',
        'Sogd' => 'sogdialainen',
        'Sogo' => 'muinaissogdialainen',
        'Sora' => 'sorang sompeng',
        'Soyo' => 'soyombo-kirjaimisto',
        'Sund' => 'sundalainen',
        'Sylo' => 'syloti nagri',
        'Syrc' => 'syyrialainen',
        'Syre' => 'syyrialainen estrangelo-muunnelma',
        'Syrj' => 'syyrialainen läntinen muunnelma',
        'Syrn' => 'syyrialainen itäinen muunnelma',
        'Tagb' => 'tagbanwalainen',
        'Takr' => 'takri',
        'Tale' => 'tailelainen',
        'Talu' => 'uusi tailuelainen',
        'Taml' => 'tamililainen',
        'Tang' => 'tangut',
        'Tavt' => 'tai viet',
        'Telu' => 'telugulainen',
        'Teng' => 'tengwar',
        'Tfng' => 'tifinagh',
        'Tglg' => 'tagalogilainen',
        'Thaa' => 'thaana',
        'Thai' => 'thailainen',
        'Tibt' => 'tiibetiläinen',
        'Tirh' => 'tirhuta',
        'Tnsa' => 'tangsa',
        'Toto' => 'toto',
        'Ugar' => 'ugaritilainen',
        'Vaii' => 'vailainen',
        'Visp' => 'näkyvä puhe',
        'Vith' => 'vithkuqi',
        'Wara' => 'varang kshiti',
        'Wcho' => 'wancholainen',
        'Wole' => 'woleai',
        'Xpeo' => 'muinaispersialainen',
        'Xsux' => 'sumerilais-akkadilainen nuolenpääkirjoitus',
        'Yezi' => 'jesidi',
        'Yiii' => 'yiläinen',
        'Zanb' => 'zanabazar-neliökirjaimisto',
        'Zinh' => 'peritty',
        'Zmth' => 'matemaattinen',
        'Zsye' => 'emoji-symbolit',
        'Zsym' => 'symbolit',
        'Zxxx' => 'kirjoittamaton',
        'Zyyy' => 'määrittämätön',
    ],
];
